diff src/cpu/x86/vm/templateInterpreter_x86_64.cpp @ 11228:e28663a9f5ef

fixed bug in java.util.zip.CRC32.update(int b) interpreter entry stub and re-enabled CRC32 intrinsics
author Doug Simon <doug.simon@oracle.com>
date Tue, 06 Aug 2013 18:31:23 +0200
parents 6b0fd0964b87
children 5c153c59ba62
line wrap: on
line diff
--- a/src/cpu/x86/vm/templateInterpreter_x86_64.cpp	Tue Aug 06 18:10:44 2013 +0200
+++ b/src/cpu/x86/vm/templateInterpreter_x86_64.cpp	Tue Aug 06 18:31:23 2013 +0200
@@ -925,7 +925,7 @@
     address entry = __ pc();
 
     // rbx,: Method*
     // rsi: senderSP must preserved for slow path, set SP to it on fast path
     // rdx: scratch
     // rdi: scratch
 
@@ -956,7 +956,7 @@
 
     // _areturn
     __ pop(rdi);                // get return address
-    __ mov(rsp, rsi);           // set sp to sender sp
+    __ mov(rsp, r13);           // set sp to sender sp
     __ jmp(rdi);
 
     // generate a vanilla native entry as the slow path
@@ -925,7 +925,7 @@
 
     // rbx,: Method*
-    // rsi: senderSP must preserved for slow path, set SP to it on fast path
+    // r13: senderSP must preserved for slow path, set SP to it on fast path
     // rdx: scratch
     // rdi: scratch